using MdlIsoReaderDotNetSDK;
using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.IO;
using System.Linq;
using System.Runtime.InteropServices.WindowsRuntime;
using System.Threading;
using System.Threading.Tasks;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.Graphics.Imaging;
using Windows.Media.Capture;
using Windows.Storage;
using Windows.Storage.Streams;
using Windows.UI.Core;
using CommunityToolkit.WinUI.UI.Controls;
using Microsoft.UI.Xaml;
using Microsoft.UI.Xaml.Controls;
using Microsoft.UI.Xaml.Controls.Primitives;
using Microsoft.UI.Xaml.Data;
using Microsoft.UI.Xaml.Input;
using Microsoft.UI.Xaml.Media;
using Microsoft.UI.Xaml.Navigation;
using System.ComponentModel;
using System.Diagnostics.Metrics;
using Microsoft.UI.Xaml.Media.Imaging;
using System.Drawing;
using ZXing;
using Image = System.Drawing.Image;
// The Blank Page item template is documented at https://go.microsoft.com/fwlink/?LinkId=402352&clcid=0x409

namespace ExampleWinUI3ReaderApp
{
    /// <summary>
    /// An empty page that can be used on its own or navigated to within a Frame.
    /// </summary>
    public sealed partial class MainPage : Page
    {
        public MainPage()
        {
            this.InitializeComponent();
            Current = this;
        }
        public static MainPage Current;
        private async void TestQr_Click(object sender, RoutedEventArgs e)
        {
            string staticQRonline = "mdoc:owBjMS4wAYIB2BhYS6QBAiABIVggw-NpXkyndhmh8UNb2qWFMakPeAlGimldtyAmBKn9bQUiWCAGyIdNUg1iyFM3yREflFVHeeHU_0nkFoM5pzsKsxofhgOhZndlYkFwaYMBeCtodHRwczovL2FwaS5kZXYuZ2xvYmFsLm1kb2MuaWQvYXBpL0lzbzE4MDEzdGVXcWJYODFCRTBMYVQxY3VtaGdo";
            await HandleScanResult(staticQRonline, true);
        }

        private async void ScanQr_Click(object sender, RoutedEventArgs e)
        {
            var dialog = new CameraCaptureUI();
            // var aspectRatio = new Size(16, 9); //dialog.PhotoSettings.CroppedAspectRatio = aspectRatio;
            StorageFile file = await dialog.CaptureFileAsync(CameraCaptureUIMode.Photo);
            var fi = new FileInfo(file.Path); if(fi.Length == 0) { return; }
            IBarcodeReaderGeneric reader = new BarcodeReaderGeneric();
            var barcodeBitmap = (Bitmap)Image.FromFile(file.Path);
            var result = reader.Decode(barcodeBitmap);
            if (result == null) { await App.MessageBox("No QR found"); }
            else { await HandleScanResult(result.Text, false); }
        }

        public async Task HandleScanResult(string qrCode, bool bOnline = false)
        {
            var reader = MdlReader.Instance;
            var ts = new CancellationTokenSource();
            // if you want to cancel from UI call ts.Cancel()
            // Get the path to the app's Certificates folder.
            string path = Windows.ApplicationModel.Package.Current.InstalledLocation.Path + @"\Certificates";
            string licenseText = @"bmJTY2BTZHpNeWReaWkBIXJPc25VBmc5ZR0hbXk1bAA9fXE1DW5CamAMKh04BBE3Dx88GRIhEB02GxE7
EB0BIRE0Dx06BBMxEh4sGxE7EB02GxEMKmNtRkQ7ZkRgQlFxT14BIWlgUkl7SlNkaWk2G29QF2A+b2Ms
bHVeZGZTcnkhG2BLcG5Gc2Asbxw+cng0bhshfXVKFiAGRRlYTlttBEA1aGN+GRJKUGMnAG5KaX1gTnBn
DxxLT2VwYURbQEx3D1U4c21MZBh0blkyQxRnQ21icXtuExR7VgI9X3d0RXpaQWpoTFh7Q1czR0JnSWNX
eG8/akc3SGB6fGpNWgJGTWBlV0M/THFgURlUXRc4dk89RHJXZUJESXV7FmRIHkR7D0hdHk9Oa0dmYxB3
SUJrGxFlcRViaWtycGtuHXRVQml5YUhUHQ==";
            string errorMessage = reader.Initialize(new ReaderSettings
            {
                DefaultRequestMode = RequestMode.All,
                LicenseText = licenseText,
                UserName = "Filippos",
                EnableOnline = bOnline,
                DebugEnabled = true,
                CertificatesPath = path
            });
            if (!string.IsNullOrEmpty(errorMessage))
            {
                await App.MessageBox(errorMessage);
                return;
            }
            MdlResponse response = await reader.RequestRead(qrCode, ts.Token);
            if (!string.IsNullOrEmpty(response.ErrorMessage))
            { await App.MessageBox(response.ErrorMessage); }
            else
            {
                dataGrid1.ItemsSource = response.Items;
                dataGridDS.ItemsSource = response.DSCertificateInfo;
                if (response.IACACertificateInfo != null)
                { dataGridIACA.ItemsSource = response.IACACertificateInfo; }
                else
                { dataGridIACA.Visibility = Visibility.Collapsed; }
                securityChecksChk.IsChecked = response.SecurityChecksPassedOK;
            }
            if (response.Portrait != null && response.Portrait.Length > 0)
            {
                var img = new BitmapImage();
                var ms = new MemoryStream(response.Portrait);
                await img.SetSourceAsync(ms.AsRandomAccessStream());
                portraitImage.Source = img;
            }
        }


    } // end class
}
